binds

package
v0.0.0-...-74a3c48 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Context

func Context(ctx context.Context) kong.Option

func Metrics

func Metrics(registry *prometheus.Registry) []kong.Option

Metrics binds the Prometheus registry to the Kong context. It registers the Go collector, build info collector, and process collector. If the registry is nil, a new registry is created. This allows to pass in one for testing.

Types

This section is empty.

Jump to